three3d/objects/index library

Functions

checkBufferGeometryIntersection(Object3D object, Material material, Raycaster raycaster, Ray ray, BufferAttribute<NativeArray<num>> position, dynamic morphPosition, dynamic morphTargetsRelative, dynamic uv, dynamic uv2, int a, int b, int c) → Intersection?
checkIntersection(Object3D object, Material material, Raycaster raycaster, Ray ray, Vector3 pA, Vector3 pB, Vector3 pC, Vector3 point) → Intersection?
testPoint(Vector3 point, num index, num localThresholdSq, Matrix4 matrixWorld, Raycaster raycaster, List<Intersection> intersects, Object3D object) → void
transformVertex(dynamic vertexPosition, Vector3 mvPosition, Vector2 center, dynamic scale, double? sin, double? cos) → void