StringKeyframeTrack class

A Track that interpolates Strings

Inheritance

Constructors

StringKeyframeTrack(dynamic name, dynamic times, dynamic values, dynamic interpolation)

Properties

createInterpolant ↔ Function?
getter/setter pairinherited
defaultInterpolation ↔ int
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeBufferType ↔ String
getter/setter pairinherited
times ↔ List<num>
getter/setter pairinherited
valueBufferType ↔ String
getter/setter pairinherited
values ↔ List<num>
getter/setter pairinherited
valueTypeName ↔ String
getter/setter pairinherited

Methods

clone() → dynamic
inherited
getInterpolation() → dynamic
inherited
getValueSize() → dynamic
inherited
interpolantFactoryMethodDiscrete(dynamic result) → Interpolant?
inherited
interpolantFactoryMethodLinear(dynamic result) → Interpolant?
override
interpolantFactoryMethodSmooth(dynamic result) → Interpolant?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optimize() → dynamic
inherited
scale(dynamic timeScale) → dynamic
inherited
setInterpolation(dynamic interpolation) → dynamic
inherited
shift(dynamic timeOffset) → dynamic
inherited
toString() → String
A string representation of this object.
inherited
trim(dynamic startTime, dynamic endTime) → dynamic
inherited
validate() → dynamic
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited