LoadingManager class

Constructors

LoadingManager([Function? onLoad, Function? onProgress, Function? onError])

Properties

handlers ↔ List
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isLoading ↔ bool
getter/setter pair
itemsLoaded ↔ int
getter/setter pair
itemsTotal ↔ int
getter/setter pair
onError ↔ Function?
getter/setter pair
onLoad ↔ Function?
getter/setter pair
onProgress ↔ Function?
getter/setter pair
onStart ↔ Function?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
urlModifier ↔ Function?
getter/setter pair

Methods

addHandler(RegExp regex, Loader loader) → dynamic
getHandler(dynamic file) → dynamic
itemEnd(dynamic url) → dynamic
itemError(dynamic url) → dynamic
itemStart(String url) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeHandler(RegExp regex) → dynamic
resolveURL(dynamic url) → dynamic
setURLModifier(dynamic transform) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited