Box2 class

Constructors

Box2(Vector2? min, Vector2? max)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isBox2 ↔ bool
getter/setter pair
max ↔ Vector2
getter/setter pair
min ↔ Vector2
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clampPoint(Vector2 point, Vector2 target) → Vector2
clone() → Box2
containsBox(Box2 box) → bool
containsPoint(Vector2 point) → bool
copy(Box2 box) → Box2
distanceToPoint(Vector2 point) → num
equals(Box2 box) → bool
expandByPoint(Vector2 point) → Box2
expandByScalar(double scalar) → Box2
expandByVector(Vector2 vector) → Box2
getCenter(Vector2 target) → Vector2
getParameter(Vector2 point, Vector2 target) → Vector2
getSize(Vector2 target) → Vector2
intersect(Box2 box) → Box2
intersectsBox(Box2 box) → bool
isEmpty() → bool
makeEmpty() → Box2
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(Vector2 min, Vector2 max) → Box2
setFromCenterAndSize(Vector2 center, Vector2 size) → Box2
setFromPoints(List<Vector2> points) → Box2
toString() → String
A string representation of this object.
inherited
translate(Vector2 offset) → Box2
union(Box2 box) → Box2

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

infinity ↔ double
getter/setter pair