Box3 class

Constructors

Box3([Vector3? min, Vector3? max])

Properties

hashCode → int
The hash code for this object.
no setterinherited
max ↔ Vector3
getter/setter pair
min ↔ Vector3
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pair

Methods

applyMatrix4(Matrix4 matrix) → Box3
clampPoint(dynamic point, Vector3 target) → Vector3
clone() → Box3
containsBox(Box3 box) → bool
containsPoint(Vector3 point) → bool
copy(Box3 box) → Box3
distanceToPoint(Vector3 point) → double
equals(Box3 box) → bool
expandByObject(Object3D object, [bool precise = false]) → Box3
expandByPoint(Vector3 point) → Box3
expandByScalar(num scalar) → Box3
expandByVector(Vector3 vector) → Box3
getBoundingSphere(Sphere target) → Sphere
getCenter(Vector3 target) → Vector3
getParameter(Vector3 point, Vector3 target) → Vector3
getSize(Vector3 target) → Vector3
intersect(Box3 box) → Box3
intersectsBox(Box3 box) → bool
intersectsPlane(Plane plane) → bool
intersectsSphere(Sphere sphere) → bool
intersectsTriangle(Triangle triangle) → bool
isEmpty() → bool
makeEmpty() → Box3
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
satForAxes<T extends num>(List<T> axes, Vector3 v0, Vector3 v1, Vector3 v2, Vector3 extents) → bool
set(Vector3 min, Vector3 max) → Box3
setFromArray(List<double> array) → Box3
setFromBufferAttribute(BufferAttribute<NativeArray<num>> attribute) → Box3
setFromCenterAndSize(Vector3 center, Vector3 size) → Box3
setFromObject(Object3D object, [bool precise = false]) → Box3
setFromPoints(List<Vector3> points) → Box3
toJSON() → List
toString() → String
A string representation of this object.
inherited
translate(Vector3 offset) → Box3
union(Box3 box) → Box3

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

infinity ↔ double
getter/setter pair