Matrix3 class

Constructors

Matrix3()
Matrix3.fromJson(Map<String, dynamic> json)

Properties

elements ↔ Float32Array
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pair

Methods

clone() → Matrix3
copy(dynamic m) → Matrix3
determinant() → num
dispose() → void
equals(Matrix3 matrix) → bool
extractBasis(Vector3 xAxis, Vector3 yAxis, Vector3 zAxis) → Matrix3
fromArray(Float32Array array, {int offset = 0}) → Matrix3
getNormalMatrix(Matrix4 matrix4) → Matrix3
identity() → Matrix3
invert() → Matrix3
multiply(Matrix3 m) → Matrix3
multiplyMatrices(Matrix3 a, Matrix3 b) → Matrix3
multiplyScalar(num s) → Matrix3
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
premultiply(Matrix3 m) → Matrix3
rotate(double theta) → Matrix3
scale(double sx, double sy) → Matrix3
set(double n11, double n12, double n13, double n21, double n22, double n23, double n31, double n32, double n33) → Matrix3
setFromMatrix4(Matrix4 m) → Matrix3
setUvTransform(num tx, num ty, num sx, num sy, num rotation, num cx, num cy) → Matrix3
toArray(List<num> array, {int offset = 0}) → List<num>
toJSON() → dynamic
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
translate(num tx, num ty) → Matrix3
transpose() → Matrix3
transposeIntoArray(List<num> r) → Matrix3

Operators

operator ==(Object other) → bool
The equality operator.
inherited