Ray class

Constructors

Ray([Vector3? origin, Vector3? direction])

Properties

direction ↔ Vector3
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
origin ↔ Vector3
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyMatrix4(Matrix4 matrix4) → Ray
at(num t, dynamic target) → dynamic
clone() → Ray
closestPointToPoint(Vector3 point, Vector3 target) → Vector3
copy(Ray ray) → Ray
distanceSqToPoint(Vector3 point) → num
distanceSqToSegment(Vector3 v0, Vector3 v1, [Vector3? optionalPointOnRay, Vector3? optionalPointOnSegment]) → num
distanceToPlane(Plane plane) → num?
distanceToPoint(Vector3 point) → double
equals(Ray ray) → bool
intersectBox(Box3 box, Vector3 target) → Vector3?
intersectPlane(Plane plane, Vector3 target) → dynamic
intersectsBox(Box3 box) → bool
intersectSphere(Sphere sphere, Vector3 target) → Vector3?
intersectsPlane(Plane plane) → bool
intersectsSphere(Sphere sphere) → bool
intersectTriangle(Vector3 a, Vector3 b, Vector3 c, bool backfaceCulling, Vector3 target) → Vector3?
lookAt(Vector3 v) → Ray
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recast(double t) → Ray
set(Vector3 origin, Vector3 direction) → Ray
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited