Sphere class

Constructors

Sphere([Vector3? center, double? radius])

Properties

center ↔ Vector3
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
radius ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyMatrix4(Matrix4 matrix) → Sphere
clampPoint(Vector3 point, Vector3 target) → Vector3
clone() → Sphere
containsPoint(Vector3 point) → bool
copy(Sphere sphere) → Sphere
distanceToPoint(Vector3 point) → double
equals(Sphere sphere) → bool
expandByPoint(Vector3 point) → Sphere
getBoundingBox(Box3 target) → Box3
intersectsBox(Box3 box) → bool
intersectsPlane(Plane plane) → bool
intersectsSphere(Sphere sphere) → bool
isEmpty() → bool
makeEmpty() → Sphere
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(Vector3 center, double radius) → Sphere
setFromPoints(List<Vector3> points, [Vector3? optionalCenter]) → Sphere
toJSON() → List<num>
toString() → String
A string representation of this object.
inherited
translate(Vector3 offset) → Sphere
union(Sphere sphere) → Sphere

Operators

operator ==(Object other) → bool
The equality operator.
inherited