Vector4 class

Constructors

Vector4([num? x, num? y, num? z, num? w])
Vector4.fromJSON(List<num>? json)
Vector4.fromJson(Map<String, dynamic> json)
Vector4.init({num x = 0, num y = 0, num z = 0, num w = 1})

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pair
w ↔ num
getter/setter pair
width ↔ dynamic
getter/setter pair
x ↔ num
getter/setter pair
y ↔ num
getter/setter pair
z ↔ num
getter/setter pair

Methods

add(Vector4 v) → Vector4
addScalar(num s) → Vector4
addScaledVector(Vector4 v, num s) → Vector4
addVectors(Vector4 a, Vector4 b) → Vector4
applyMatrix4(Matrix4 m) → Vector4
ceil() → Vector4
clamp(Vector4 min, Vector4 max) → Vector4
clampLength(num min, num max) → Vector4
clampScalar(num minVal, num maxVal) → Vector4
clone() → Vector4
copy(Vector4 v) → Vector4
divideScalar(num scalar) → Vector4
dot(Vector4 v) → num
equals(Vector4 v) → bool
floor() → Vector4
fromArray(List<num> array, [int offset = 0]) → Vector4
fromBufferAttribute(BufferAttribute<NativeArray<num>> attribute, int index) → Vector4
getComponent(int index) → num
length() → double
lengthSq() → num
lerp(Vector4 v, num alpha) → Vector4
lerpVectors(Vector4 v1, Vector4 v2, num alpha) → Vector4
manhattanLength() → num
max(Vector4 v) → Vector4
min(Vector4 v) → Vector4
multiply(Vector4 v) → Vector4
multiplyScalar(num scalar) → Vector4
negate() → Vector4
normalize() → Vector4
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
random() → Vector4
round() → Vector4
roundToZero() → Vector4
set(num x, num y, num z, num w) → Vector4
setAxisAngleFromQuaternion(Quaternion q) → Vector4
setAxisAngleFromRotationMatrix(Matrix3 m) → Vector4
setComponent(int index, num value) → Vector4
setLength(num length) → Vector4
setScalar(num scalar) → Vector4
setW(num w) → Vector4
setX(num x) → Vector4
setY(num y) → Vector4
setZ(num z) → Vector4
sub(Vector4 v, Vector4? w) → Vector4
subScalar(num s) → Vector4
subVectors(Vector4 a, Vector4 b) → Vector4
toArray(List<num> array, [int offset = 0]) → List<num>
toJSON() → List<num>
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited