ImageElement class

Constructors

ImageElement({dynamic url, dynamic data, int width = 1, int height = 1, int depth = 1})

Properties

complete ↔ bool
getter/setter pair
data ↔ dynamic
getter/setter pair
depth ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
src ↔ String?
getter/setter pair
url ↔ dynamic
getter/setter pair
uuid ↔ String?
getter/setter pair
width ↔ int
getter/setter pair

Methods

dispose() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited