Source class

Constructors

Source([dynamic data])

Properties

currentVersion ↔ int
getter/setter pair
data ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
needsUpdate ← dynamic
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uuid ↔ String
getter/setter pair
version ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON(dynamic meta) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited